@@ -5,7 +5,7 @@ use Mojolicious::Plugin::Vparam::Common qw(:all);
 use version;
 use List::MoreUtils qw(firstval natatime mesh);
 
-our $VERSION    = '2.07';
+our $VERSION    = '2.08';
 
 # Regext for shortcut parser
 our $SHORTCUT_REGEXP = qr{
@@ -320,10 +320,14 @@ sub register {
                 if( $attr{array} ) {
                     die 'Array of arrays not supported';
                 } else {
+                    my $regexp = 'Regexp' eq ref $attr{multiline}
+                         ? $attr{multiline}
+                         : qr{\r?\n}
+                    ;
                     # Apply multiline
                     @input =
                         grep { $_ =~ m{\S} }
-                        map  { split m{\r?\n}, $_ } @input;
+                        map  { split $regexp, $_ } @input;
                 }
 
                 # Multiline force array
@@ -449,7 +453,10 @@ sub register {
             if( $attr{hash} ) {
                 $result{ $name } = { mesh @keys, @output };
             } elsif( $attr{array} ) {
-                $result{ $name } = \@output;
+                $result{ $name } = defined $attr{multijoin}
+                    ? join $attr{multijoin}, @output
+                    : \@output
+                ;
             } else {
                 $result{ $name } = $output[0]
                     unless $attr{skipundef} and not defined($output[0]);
@@ -698,9 +705,13 @@ If you set undef then parameter is not apply.
 Get parameter error string. Return 0 if no error.
 
     # Get error
-    print $self->verror('myparam') || 'Ok';
+    print $self->verror('myparam');
+
+    # Get error for first element in array
+    print $self->verror('myparam' => 0);
+
     # Set error
-    $self->verror('myparam', {message => 'Error message'})
+    $self->verror('myparam', message => 'Error message')
 
 =head2 verrors
 
@@ -1285,7 +1296,10 @@ if it`s undefined by set I<skipundef>.
     # Shortcut syntax: skipundef and optional is on
     $param2 = $self->vparam(param2 => '~int');
 
-Arrays always return as arrayref. But undefined values will be skipped.
+Arrays always return as arrayref. But undefined values will be skipped:
+
+    # This vparam return [1,2,3] for ?param3=1&param3=&param3=2&param3=3
+    $param2 = $self->vparam(param3 => '~int');
 
 =head2 multiline
 
@@ -1294,8 +1308,22 @@ You can simple split I<textarea> to values:
     # This vparam return [1,2,3] for input "1\n2\n3\n"
     $param1 = $self->vparam(param1 => 'int', multiline => 1);
 
+    # Or by custom regexp
+    # This vparam return [1,2,3] for input "1,2,3"
+    $param1 = $self->vparam(param1 => 'int', multiline => qr{\s*,\s*});
+
 Empty lines ignored.
 
+=head2 multijoin
+
+Any array values can be joined in string:
+
+    # This vparam return "1,2,3" for input ?param1=1&param1=2&param1=3
+    $param1 = $self->vparam(param1 => 'int', multijoin => ',');
+
+    # This vparam return "1,2,3" for input "1\n2\n3\n"
+    $param2 = $self->vparam(param2 => 'int', multiline => 1, multijoin => ',');
+
 =head2 blessed
 
 Keep and return blessed object for parsed parameters if available.
@@ -1390,6 +1418,20 @@ Check maximum parameter value.
     # Error if myparam greater than 100
     $self->vparam(myparam => 'int', max => 100);
 
+=head2 equal
+
+Check parametr equal.
+
+    # Error if myparam not equal 100
+    $self->vparam(myparam => 'int', equal => 100);
+
+=head2 not
+
+Check parametr not equal.
+
+    # Error if myparam equal 100
+    $self->vparam(myparam => 'int', not => 100);
+
 =head2 range
 
 Check parameter value to be in range.
@@ -1418,6 +1460,10 @@ Check maximum length in utf8.
     # Error if value is an empty string
     $self->vparam(myparam => 'str', size => [1, 100]);
 
+=head2 String comparations
+
+    I<lt>, I<gt>, I<le>, I<ge>, I<cmp>, I<eq>, I<ne>
+
 =head1 RESTRICTIONS
 
 =over
